## Intugien Parser 

to get different database elements like 

* `createdAt`
* `telephone`
* `startTime`
* `endTime`
* `eta_days`
* `eta_hrs`
* `ping_rate`
* `source`
* `destination`
* `operator`
* `trucknumber`
* `running`
* `invoice`
* `telephone`
    
    
---

## Itugine Helper

To get database and other trips related things